* Rust for Org Babel

=ob-rust.el= has been adapted from =ob-C.el= and provides pretty much the same
features.

Basic functionality:

#+BEGIN_SRC rust
  fn main() {
      println!("Hello world");
  }
#+END_SRC

#+RESULTS:
: Hello world

Don't need to specify main if that's the only function we have:

#+BEGIN_SRC rust
  println!("Hello world");
#+END_SRC

#+RESULTS:
: Hello world

We can specify variables:

#+BEGIN_SRC rust :var x="Hello world"
  println!("{}", x);
#+END_SRC

#+RESULTS:
: Hello world

We support =int=s, =f64=, strings and lists of any of those:

#+HEADER: :var n=42
#+HEADER: :var pi=3.14
#+HEADER: :var s="Hello"
#+HEADER: :var l='(1 2 3 4)
#+BEGIN_SRC rust
  println!("n = {}, pi = {}, s = {}, l = {}", n, pi, s, l);
#+END_SRC

#+RESULTS:
| n = 42 | pi = 3.14 | s = Hello | l = [1 | 2 | 3 | 4] |

We can also use modules, extern crates and set attributes:

#+HEADER: :uses std::mem::size_of
#+HEADER: :externs getopts
#+HEADER: :attributes feature(globs)
#+BEGIN_SRC rust
  println!("{}", size_of::<String>());
#+END_SRC

#+RESULTS:
: 24

#+HEADER: :uses '(std::mem::size_of std::mem::transmute)
#+BEGIN_SRC rust
  println!("Hello world");
#+END_SRC

#+RESULTS:
: Hello world
